'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var R = require('ramda');
var T = require('folktale/concurrency/task');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var R__default = /*#__PURE__*/_interopDefaultLegacy(R);
var T__default = /*#__PURE__*/_interopDefaultLegacy(T);

/**
 * Created by Andy Likuski on 2019.06.05
 * Copyright (c) 2019 Andy Likuski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
const {
  of
} = T__default['default'];
/**
 * Returns a Task.of if we are doing an ApolloClient request.
 * For components return a component expecting a render prop that is called with obj: children => children(obj)
 * @param {Object} apolloConfig
 * @param {Object} apolloConfig.apolloClient If present then of is returned
 * @param {Object} responseAndOptionalRender
 * @param {Function} render The render function to call. Required only for components
 * @param {Object} the response. This must match the Apollo response format {loading, data, etc.}
 * @returns {Task|Function} a task that resolves to the props or a component that when called
 * finds the render props and calls that with the props
 */

const containerForApolloType = R__default['default'].curry((apolloConfig, responseAndOptionalRender) => {
  return R__default['default'].ifElse(R__default['default'].always(R__default['default'].propOr(false, 'apolloClient', apolloConfig)), responseAndOptionalRender => {
    // If responseAndOptionalRender is {response, render}, extract response
    return of(R__default['default'].when(R__default['default'].has('response'), R__default['default'].prop('response'))(responseAndOptionalRender));
  }, responseAndOptionalRender => {
    const {
      render,
      response
    } = responseAndOptionalRender;
    return render(response);
  })(responseAndOptionalRender);
});

exports.containerForApolloType = containerForApolloType;
//# sourceMappingURL=containerHelpers.js.map
