'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var R = require('ramda');
require('util');
require('safe-json-stringify');
require('ramda-lens');
require('pluralize');
var rescapeRamda = require('rescape-ramda');
var Result = require('folktale/result');
var requestHelpers = require('./requestHelpers.js');
require('@apollo/client');
require('@apollo/link-context');
require('@apollo/link-error');
require('folktale/concurrency/task');
var maybe = require('folktale/maybe');
require('react-apollo');
require('rescape-helpers-component');
require('graphql');
require('node-fetch');
require('rescape-log');
require('apollo-cache-persist');
require('rescape-validate');
require('prop-types');
var apolloClient = require('./apolloClient.js');
require('ramda/src/index');
var mutationHelpers = require('./mutationHelpers.js');
var containerHelpers = require('./containerHelpers.js');
var apolloClientCache = require('./apolloClientCache-855e9291.js');
require('inflected');
var queryHelpers = require('./queryHelpers.js');
var utilityHelpers = require('./utilityHelpers.js');
var mutationCacheHelpers = require('./mutationCacheHelpers.js');
var queryCacheHelpers = require('./queryCacheHelpers.js');
var login = require('./login-a898b78e.js');
var defaultSettingsStore = require('./defaultSettingsStore-b9a20f38.js');
var testHelpers = require('./testHelpers-e306425e.js');
require('rescape-helpers');
var clientHelpers = require('./clientHelpers.js');
var config = require('./config.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var R__default = /*#__PURE__*/_interopDefaultLegacy(R);
var Result__default = /*#__PURE__*/_interopDefaultLegacy(Result);
var maybe__default = /*#__PURE__*/_interopDefaultLegacy(maybe);

/**
 * Created by Andy Likuski on 2018.05.09
 * Copyright (c} 2018 Andy Likuski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"}, to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
/**
 * Example of a sankey setting data structure that can be defined on resource.data
 * @type {{settings: {value_key: string, default_location: number[], columns: [string, string, string, string, string], stages: ({name: string, targets: [string], key: string}|{name: string, targets: [string], key: string}|{name: string, targets: [string], key: string}|{name: string, targets: [string, string], key: string}|{name: string, targets: [string], key: string})[], node_name_key: string, location_key: string, stage_key: string}}}
 */

const sample_resource_data = {
  settings: {
    default_location: [4.3517, 50.8503],
    columns: ['siteName', 'location', 'coordinates', 'junctionStage', 'annualTonnage'],
    stage_key: 'junctionStage',
    value_key: 'annualTonnage',
    location_key: 'coordinates',
    node_name_key: 'siteName',
    stages: [{
      key: 'source',
      name: 'Source',
      targets: ['conversion']
    }, {
      key: 'conversion',
      name: 'Conversion',
      targets: ['distribution']
    }, {
      key: 'distribution',
      name: 'Distribution',
      targets: ['demand']
    }, {
      key: 'demand',
      name: 'Demand',
      targets: ['reconversion', 'sink']
    }, {
      key: 'reconversion',
      name: 'Reconversion',
      targets: ['demand']
    }, {
      key: 'sink',
      name: 'Sink',
      targets: []
    }]
  }
};
const sampleResources = R__default['default'].map(resource => rescapeRamda.mergeDeep(resource, {
  data: sample_resource_data
}), [{
  name: 'Minerals',
  data: {
    material: 'Minerals',
    raw_data: ['Other Global Imports;Shipments, location generalized;51.309933, 3.055030;Source;22,469,843', 'Knauf (Danilith} BE;Waregemseweg 156-142 9790 Wortegem-Petegem, Belgium;50.864762, 3.479308;Conversion;657,245', "MPRO Bruxelles;Avenue du Port 67 1000 Bruxelles, Belgium;50.867486, 4.352543;Distribution;18,632", 'Residential Buildings (all typologies};Everywhere in Brussels;NA;Demand;3,882,735', 'Duplex House Typology;Everywhere in Brussels;NA;Demand;13,544', 'Apartment Building Typology;Everywhere in Brussels;NA;Demand;34,643', 'New West Gypsum Recycling;9130 Beveren, Sint-Jansweg 9 Haven 1602, Kallo, Belgium;51.270229, 4.261048;Reconversion;87,565', 'Residential Buildings (all typologies};Everywhere in Brussels;NA;Sink;120,000', 'RecyPark South;1190 Forest, Belgium;50.810799, 4.314789;Sink;3,130', 'RecyPark Nord;Rue du Rupel, 1000 Bruxelles, Belgium;50.880181, 4.377136;Sink;1,162']
  }
}, {
  name: 'Metals',
  data: {
    material: 'Metals',
    raw_data: ['Other Global Imports;Shipments, location generalized;51.309933, 3.055030;Source;367,689', 'Arcelor Steel Belgium;Lammerdries 10, 2440 Geel, Belgium;51.145051, 4.939373;Conversion;27,872', 'Duplex House Typology;Everywhere in Brussels;NA;Demand;3,048', 'Apartment Building Typology;Everywhere in Brussels;NA;Demand;18,548', 'Residential Buildings (all typologies};Everywhere in Brussels;NA;Demand;75,404', 'Metallo Belgium;Nieuwe Dreef 33, 2340 Beerse, Belgium;51.318025, 4.817432;Reconversion;54,000', 'Private Sector Collection;Everywhere in Brussels;NA;Sink;96,316', 'RecyPark South;1190 Forest, Belgium;50.810799, 4.314789;Sink;101', 'RecyPark Nord;Rue du Rupel, 1000 Bruxelles, Belgium;50.880181, 4.377136;Sink;67']
  }
}, {
  name: 'Wood',
  data: {
    material: 'Wood',
    raw_data: ['Forêt de Soignes;Watermael-Boitsfort Belgium ;50.777072, 4.409960;Source;6,288', 'Germany Imports;Germany, nearest point;50.786952, 6.102697;Source;66,812', 'Netherlands Imports;Netherlans, nearest point;51.467197, 4.609125;Source;52,352', 'Other Global Imports;Shipments, location generalized;51.309933, 3.055030;Source;323,384', 'Barthel Pauls Sawmill;Pôle Ardenne Bois 1, 6671 Bovigny, Belgium;50.259872, 5.933474;Conversion;200,430', "Lochten & Germeau;Bd de l’Humanité, 51, 1190 Vorst, Belgium;50.820974, 4.314469;Distribution; NA, only for directional/path", 'Duplex House Typology;Everywhere in Brussels;NA;Demand;1,955', 'Apartment Building Typology;Everywhere in Brussels;NA;Demand;11,250', 'Residential Buildings (all typologies};Everywhere in Brussels;NA;Demand;45,659', 'Rotor Deconstruction;Prévinairestraat / Rue Prévinaire 58 1070 Anderlecht;50.839714, 4.352730;Reconversion;15,462', 'PAC Uccle;Boulevard de la Deuxième Armée Britannique 625-667 1190 Forest, Belgium;50.801647, 4.305641;Sink;189', 'PAC Saint-Josse;Rue Verboeckhaven 39-17 1210 Saint-Josse-ten-Noode, Belgium;50.854094, 4.375173;Sink;126', 'PAC Woluwe-Saint-Pierre;Avenue du Parc de Woluwe 86-44 1160 Auderghem, Belgium;50.823228, 4.427453;Sink;63.08', "PAC d’Auderghem/Watermael-Boitsfort;1860 chaussée de Wavre, 1160 Auderghem;50.809948, 4.445271;Sink;252.32", "RecyPark South;1190 Forest, Belgium;50.810799, 4.314789;Sink;668", "RecyPark Nord;Rue du Rupel, 1000 Bruxelles, Belgium;50.880181, 4.377136;Sink;445"]
  }
}]); // data would default to Object, so we need to map it to the right type

const sampleInputParamTypeMapper = {
  'resourceData': 'ResourceRelatedReadInputType'
}; // Default output params for query. Just add more to these as needed.
// Later we'll let the user specify

const sampleResourceOutputParams = {
  id: 1,
  name: 1,
  data: {
    settings: {
      defaultLocation: 1,
      stages: {
        key: 1,
        targets: 1
      }
    },
    rawData: 1,
    material: 1,
    graph: {
      'nodes': {
        name: 1,
        type: 1,
        value: 1,
        geometry: {
          type: 1,
          coordinates: 1
        },
        properties: 1,
        propertyValues: 1
      },
      links: {
        value: 1,
        source: 1,
        target: 1
      }
    }
  }
};
const sampleResourceProps = {
  resourceData: {
    name: "Candy",
    data: {
      settings: {
        defaultLocation: [4.3517, 50.8503],
        columns: {
          siteName: 1,
          location: 1,
          coordinates: 1,
          junctionStage: 1,
          annualTonnage: 1
        },
        stageKey: "junctionStage",
        valueKey: "annualTonnage",
        locationKey: "coordinates",
        nodeNameKey: "siteName",
        stages: [{
          key: "source",
          name: "Source",
          targets: ["conversion"]
        }, {
          key: "conversion",
          name: "Conversion",
          targets: ["distribution"]
        }, {
          key: "distribution",
          name: "Distribution",
          targets: ["demand"]
        }, {
          key: "demand",
          name: "Demand",
          targets: ["reconversion", "sink"]
        }, {
          key: "reconversion",
          name: "Reconversion",
          targets: ["demand"]
        }, {
          key: "sink",
          name: "Sink",
          targets: []
        }]
      },
      material: "Candy",
      rawData: ["Other Global Imports;Shipments, location generalized;51.309933, 3.055030;Source;22,469,843", "Knauf (Danilith) BE;Waregemseweg 156-142 9790 Wortegem-Petegem, Belgium;50.864762, 3.479308;Conversion;657,245", "MPRO Bruxelles;Avenue du Port 67 1000 Bruxelles, Belgium;50.867486, 4.352543;Distribution;18,632", "Residential Buildings (all typologies);Everywhere in Brussels;NA;Demand;3,882,735", "Duplex House Typology;Everywhere in Brussels;NA;Demand;13,544", "Apartment Building Typology;Everywhere in Brussels;NA;Demand;34,643", "New West Gypsum Recycling;9130 Beveren, Sint-Jansweg 9 Haven 1602, Kallo, Belgium;51.270229, 4.261048;Reconversion;87,565", "Residential Buildings (all typologies);Everywhere in Brussels;NA;Sink;120,000", "RecyPark South;1190 Forest, Belgium;50.810799, 4.314789;Sink;3,130", "RecyPark Nord;Rue du Rupel, 1000 Bruxelles, Belgium;50.880181, 4.377136;Sink;1,162"]
    }
  }
};
const sampleResourceMutationOutputParams = {
  resource: sampleResourceOutputParams
};

/**
 * Created by Andy Likuski on 2020.04.01
 * Copyright (c) 2020 Andy Likuski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/**
 * Given a component and the props passed to it, extract the render prop or children component from the props and create a
 * render prop called render passed to component along with the other props. The children function
 * calls the extracted children component/function
 * @param component
 * @return {*}
 */

const componentRenderedWithChildrenRenderProp = component => {
  return ({
    render,
    children,
    ...props
  }) => {
    return component(R__default['default'].merge(props, {
      render: p => {
        return render ? render(p) : children(p);
      }
    }));
  };
};
const componentRenderedWithChildrenRenderPropMaybe = component => {
  return maybe__default['default'].Just(componentAndChildRenderedWithRenderProp(component));
};
/**
 * Given a component and its child component and the props passed to the component, extract the
 * render prop from the props and create a render prop called children passed to component along with
 * the other props. The children function calls childComponent with the children render prop, allowing
 * us to build-up the children via the render prop
 */

const componentAndChildRenderedWithRenderProp = R__default['default'].curry((childComponent, component) => {
  return ({
    render,
    ...props
  }) => {
    return component(R__default['default'].merge(props, {
      render: p => {
        return childComponent(R__default['default'].merge(p, {
          render
        }));
      }
    }));
  };
});
const componentAndChildRenderedWithChildrenRenderPropMaybe = R__default['default'].curry((childComponent, component) => {
  return maybe__default['default'].Just(componentAndChildRenderedWithRenderProp(childComponent, component));
});

/**
 * Created by Andy Likuski on 2020.06.09
 * Copyright (c) 2020 Andy Likuski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
/**
 * Returns a Result.Ok if data is loaded and a Result.Error if the response is loading or an error.
 * If loading the Result.Error has a loading: true key, if an error it has an error: true key
 * data, loading, error, and status are always in the Result object
 * @param apolloResponse
 * @return {*}
 */

const apolloResult = apolloResponse => {
  return R__default['default'].ifElse(R__default['default'].prop('data'), Result__default['default'].Ok, Result__default['default'].Error)(apolloResponse);
};
/**
 * Returns the data value of the apolloResult if available or else null
 * @param apolloResult
 * @return {*}
 */

const resultOkOrNull = apolloResult => {
  return apolloResult.matchWith({
    Ok: ({
      value
    }) => value,
    Error: () => null
  });
};
/**
 * Converts the Apollo query response with the given response name at response: {data: [responseName]: {}/[]}}
 * to the value at responseName or returns null if the response is loading or an error.
 * This method can be used to give Apollo request response values to components that just need
 * the value or null, and don't care if the value is loading or error. If the component needs to know,
 * the response should be given directly to the component so that it can process it
 * @param {String} responseName The string at {data: {[responseName]: [...]/{...}}
 * @param {Object} response An Apollo request response
 * @returns {Object|List<Objectd>} The single object or list of objects at responseName or null
 * for the loading/error case
 */

const apolloResponseValueOrNull = (responseName, response) => {
  return R__default['default'].compose( // Return null if status is loading or error
  apolloResult => resultOkOrNull(apolloResult), response => R__default['default'].map( // Map the data response to the data value
  response => rescapeRamda.reqStrPathThrowing(`data.${responseName}`, response), apolloResult(response)))(response);
};
/**
 * Same as apolloResponseValueOrNull, but takes the first item of the resolved value,
 * which is expected to be an array.
 * @param {String} responseName The string at {data: {[responseName]: [...]}}
 * @param {Object} response An Apollo request response
 * @returns {Object} The single value or null for the loading/error case
 */

const apolloResponseSingleValueOrNull = (responseName, response) => {
  return R__default['default'].compose(listOrNull => R__default['default'].head(listOrNull || []), response => apolloResponseValueOrNull(responseName, response))(response);
};
/**
 * Like apolloResponseValueOrNull but additionally filters each returned item if not null
 * @param {String} responseName The string at {data: {[responseName]: [...]}}
 * @param {Function} filterItem Unary filter to apply to each item
 * @param {Object} response An Apollo request response
 * @returns {[Object]} List of matching items or empty for no matches or loading/error case
 */

const apolloResponseFilterOrEmpty = (responseName, filterItem, response) => {
  return R__default['default'].compose(list => R__default['default'].filter(itm => filterItem(itm), list), R__default['default'].defaultTo([]), response => apolloResponseValueOrNull(responseName, response))(response);
};

exports.VERSION_PROPS = requestHelpers.VERSION_PROPS;
exports.createReadInputTypeMapper = requestHelpers.createReadInputTypeMapper;
exports.formatInputParams = requestHelpers.formatInputParams;
exports.formatOutputParams = requestHelpers.formatOutputParams;
exports.mapQueryContainerToNamedResultAndInputs = requestHelpers.mapQueryContainerToNamedResultAndInputs;
exports.objIdToInt = requestHelpers.objIdToInt;
exports.omitClientFields = requestHelpers.omitClientFields;
exports.omitUnrepresentedOutputParams = requestHelpers.omitUnrepresentedOutputParams;
exports.optionsWithWinnowedProps = requestHelpers.optionsWithWinnowedProps;
exports.pickGraphqlPaths = requestHelpers.pickGraphqlPaths;
exports.pickGraphqlPathsOver = requestHelpers.pickGraphqlPathsOver;
exports.relatedObjectsToIdForm = requestHelpers.relatedObjectsToIdForm;
exports.resolveGraphQLType = requestHelpers.resolveGraphQLType;
exports.versionOutputParamsMixin = requestHelpers.versionOutputParamsMixin;
exports.authApolloClientMutationRequestContainer = apolloClient.authApolloClientMutationRequestContainer;
exports.authApolloClientQueryContainer = apolloClient.authApolloClientQueryContainer;
exports.authApolloClientRequestTask = apolloClient.authApolloClientRequestTask;
exports.authApolloComponentMutationContainer = apolloClient.authApolloComponentMutationContainer;
exports.authApolloComponentQueryContainer = apolloClient.authApolloComponentQueryContainer;
exports.authApolloQueryContainer = apolloClient.authApolloQueryContainer;
exports.getApolloClientTask = apolloClient.getApolloClientTask;
exports.getOrCreateApolloClientTask = apolloClient.getOrCreateApolloClientTask;
exports.noAuthApolloClientMutationRequestTask = apolloClient.noAuthApolloClientMutationRequestTask;
exports.noAuthApolloClientQueryRequestTask = apolloClient.noAuthApolloClientQueryRequestTask;
exports.noAuthApolloClientRequestTask = apolloClient.noAuthApolloClientRequestTask;
exports.noAuthApolloClientTask = apolloClient.noAuthApolloClientTask;
exports.addMutateKeyToMutationResponse = mutationHelpers.addMutateKeyToMutationResponse;
exports.filterOutNullDeleteProps = mutationHelpers.filterOutNullDeleteProps;
exports.filterOutReadOnlyVersionProps = mutationHelpers.filterOutReadOnlyVersionProps;
exports.makeMutation = mutationHelpers.makeMutation;
exports.makeMutationRequestContainer = mutationHelpers.makeMutationRequestContainer;
exports.mutationParts = mutationHelpers.mutationParts;
exports.containerForApolloType = containerHelpers.containerForApolloType;
exports.composeWithComponentMaybeOrTaskChain = apolloClientCache.composeWithComponentMaybeOrTaskChain;
exports.getRenderProp = apolloClientCache.getRenderProp;
exports.getRenderPropFunction = apolloClientCache.getRenderPropFunction;
exports.nameComponent = apolloClientCache.nameComponent;
exports.apolloQueryResponsesTask = queryHelpers.apolloQueryResponsesTask;
exports.composePropsFilterIntoApolloConfigOptionsVariables = queryHelpers.composePropsFilterIntoApolloConfigOptionsVariables;
exports.createRequestVariables = queryHelpers.createRequestVariables;
exports.makeQuery = queryHelpers.makeQuery;
exports.makeQueryContainer = queryHelpers.makeQueryContainer;
exports.firstMatchingPathLookup = utilityHelpers.firstMatchingPathLookup;
exports.createCacheOnlyProps = mutationCacheHelpers.createCacheOnlyProps;
exports.makeCacheMutation = mutationCacheHelpers.makeCacheMutation;
exports.makeMutationWithClientDirectiveContainer = mutationCacheHelpers.makeMutationWithClientDirectiveContainer;
exports.mergeCacheable = mutationCacheHelpers.mergeCacheable;
exports.makeClientQuery = queryCacheHelpers.makeClientQuery;
exports.makeQueryFromCacheContainer = queryCacheHelpers.makeQueryFromCacheContainer;
exports.makeQueryWithClientDirectiveContainer = queryCacheHelpers.makeQueryWithClientDirectiveContainer;
exports.authClientOrLoginTask = login.authClientOrLoginTask;
exports.deleteRefreshTokenCookieMutationRequestContainer = login.deleteRefreshTokenCookieMutationRequestContainer;
exports.deleteTokenCookieMutationRequestContainer = login.deleteTokenCookieMutationRequestContainer;
exports.getOrCreateApolloClientTaskAndSetDefaults = login.getOrCreateApolloClientTaskAndSetDefaults;
exports.getOrCreateAuthApolloClientWithTokenTask = login.getOrCreateAuthApolloClientWithTokenTask;
exports.getOrCreateNoAuthApolloClientTask = login.getOrCreateNoAuthApolloClientTask;
exports.loginToAuthClientTask = login.loginToAuthClientTask;
exports.noLoginToAuthClientTask = login.noLoginToAuthClientTask;
exports.queryLocalTokenAuthContainer = login.queryLocalTokenAuthContainer;
exports.refreshTokenMutationRequestContainer = login.refreshTokenMutationRequestContainer;
exports.tokenAuthMutationContainer = login.tokenAuthMutationContainer;
exports.verifyTokenMutationRequestContainer = login.verifyTokenMutationRequestContainer;
exports.authenticatedUserLocalContainer = defaultSettingsStore.authenticatedUserLocalContainer;
exports.createCacheOnlyPropsForSettings = defaultSettingsStore.createCacheOnlyPropsForSettings;
exports.currentUserQueryContainer = defaultSettingsStore.currentUserQueryContainer;
exports.defaultSettingsCacheIdProps = defaultSettingsStore.defaultSettingsCacheIdProps;
exports.defaultSettingsCacheOnlyObjs = defaultSettingsStore.defaultSettingsCacheOnlyObjs;
exports.defaultSettingsOutputParams = defaultSettingsStore.defaultSettingsOutputParams;
exports.defaultSettingsTypenames = defaultSettingsStore.defaultSettingsTypenames;
exports.isAuthenticatedLocal = defaultSettingsStore.isAuthenticatedLocal;
exports.makeSettingsMutationContainer = defaultSettingsStore.makeSettingsMutationContainer;
exports.makeSettingsQueryContainer = defaultSettingsStore.makeSettingsQueryContainer;
exports.readInputTypeMapper = defaultSettingsStore.readInputTypeMapper;
exports.userOutputParams = defaultSettingsStore.userOutputParams;
exports.userReadInputTypeMapper = defaultSettingsStore.userReadInputTypeMapper;
exports.writeConfigToServerAndCache = defaultSettingsStore.writeConfigToServerAndCache;
exports.writeDefaultSettingsToCache = defaultSettingsStore.writeDefaultSettingsToCache;
exports.cacheOptions = testHelpers.cacheOptions;
exports.defaultStateLinkResolvers = testHelpers.defaultStateLinkResolvers;
exports.expectKeys = testHelpers.expectKeys;
exports.localTestAuthTask = testHelpers.localTestAuthTask;
exports.localTestConfig = testHelpers.localTestConfig;
exports.localTestNoAuthTask = testHelpers.localTestNoAuthTask;
exports.mergeLocalTestValuesIntoConfig = testHelpers.mergeLocalTestValuesIntoConfig;
exports.createAuthTask = clientHelpers.createAuthTask;
exports.createNoAuthTask = clientHelpers.createNoAuthTask;
exports.typePoliciesWithMergeObjects = clientHelpers.typePoliciesWithMergeObjects;
exports.typePoliciesConfig = config.typePoliciesConfig;
exports.apolloResponseFilterOrEmpty = apolloResponseFilterOrEmpty;
exports.apolloResponseSingleValueOrNull = apolloResponseSingleValueOrNull;
exports.apolloResponseValueOrNull = apolloResponseValueOrNull;
exports.apolloResult = apolloResult;
exports.componentAndChildRenderedWithChildrenRenderPropMaybe = componentAndChildRenderedWithChildrenRenderPropMaybe;
exports.componentAndChildRenderedWithRenderProp = componentAndChildRenderedWithRenderProp;
exports.componentRenderedWithChildrenRenderProp = componentRenderedWithChildrenRenderProp;
exports.componentRenderedWithChildrenRenderPropMaybe = componentRenderedWithChildrenRenderPropMaybe;
exports.resultOkOrNull = resultOkOrNull;
exports.sampleInputParamTypeMapper = sampleInputParamTypeMapper;
exports.sampleResourceMutationOutputParams = sampleResourceMutationOutputParams;
exports.sampleResourceOutputParams = sampleResourceOutputParams;
exports.sampleResourceProps = sampleResourceProps;
exports.sampleResources = sampleResources;
//# sourceMappingURL=index.js.map
